@@ -1,3 +1,4 @@
+from enum import Enum
 from typing import Dict
 from typing import List
 from typing import Tuple
@@ -6,9 +7,25 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import seaborn as sb
+from matplotlib import colors
 from rich import print
 
 
+class Colormaps(Enum):
+    """
+    Available colormaps:
+        | grey_red
+        | grey_violet
+        | grey_blue
+    """
+
+    grey_red = colors.LinearSegmentedColormap.from_list("grouping", ["lightgray", "red", "darkred"], N=128)
+    grey_violet = colors.LinearSegmentedColormap.from_list(
+        "grouping", ["lightgray", "mediumvioletred", "indigo"], N=128
+    )
+    grey_blue = colors.LinearSegmentedColormap.from_list("grouping", ["lightgray", "cornflowerblue", "darkblue"], N=128)
+
+
 def custom_plot_size(width: int, height: int, dpi: int):
     """
     Create a custom axis object of desired sizes.
